@@ -4,9 +4,10 @@ import os
 # import request
 import pandas as pd
 import time
+pd.options.display.width = 0
 
 # pandas set max column width
-pd.set_option('display.max_colwidth', 50)
+pd.set_option('display.max_colwidth', 75)
 
 
 def user_select_option(message, options):
@@ -31,7 +32,7 @@ def asana_list_todos(workspace_name,filtering):
     if filtering is None: filtering = 'due'
     
     df = asana_get_todos(workspace_name,filtering)
-    df = df[['name',"due_on", "completed", "projects", "notes"]]
+    df = df[['name',"due_on", "completed", "notes"]] # projects
     
     if filtering == 'done':
         df = df[df['completed'] == True]
@@ -120,4 +121,5 @@ def fix_past_due(workspace_name):
         all_tasks.append(result)
         
     df = pd.DataFrame(all_tasks)
-    print(df)
\ No newline at end of file
+    cols = ['gid', 'completed', 'due_on', 'name', 'notes']
+    print(df[cols])
\ No newline at end of file
